.. py-horned-owl documentation master file, created by
   sphinx-quickstart on Wed Jan 10 09:18:12 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to py-horned-owl's documentation!
=========================================

Contents
--------

.. toctree::
   :maxdepth: 2

   usage
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
